==> aql-2.2.0-sources.jar: org/ehrbase/openehr/sdk/aql/dto/containment/ContainmentNotOperator.java <==
/*
 * Copyright (c) 2023 vitasystems GmbH and Hannover Medical School.
 *
 * This file is part of project openEHR_SDK
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ehrbase.openehr.sdk.aql.dto.containment;

import java.util.Objects;

/**
 * @author Stefan Spiska
 */
public class ContainmentNotOperator implements Containment {
    private Containment containmentExpression;

    public Containment getContainmentExpression() {
        return containmentExpression;
    }

    public void setContainmentExpression(Containment containmentExpression) {
        this.containmentExpression = containmentExpression;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainmentNotOperator that = (ContainmentNotOperator) o;
        return Objects.equals(containmentExpression, that.containmentExpression);
    }

    @Override
    public int hashCode() {
        return Objects.hash(containmentExpression);
    }

    @Override
    public String toString() {
        return "ContainmentNotOperator{" + "containmentExpression=" + containmentExpression + '}';
    }
}

==> aql-2.20.0-sources.jar: org/ehrbase/openehr/sdk/aql/dto/containment/ContainmentNotOperator.java <==
/*
 * Copyright (c) 2023 vitasystems GmbH and Hannover Medical School.
 *
 * This file is part of project openEHR_SDK
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ehrbase.openehr.sdk.aql.dto.containment;

import java.util.Objects;

/**
 * @author Stefan Spiska
 */
public final class ContainmentNotOperator implements Containment {
    private Containment containmentExpression;

    public Containment getContainmentExpression() {
        return containmentExpression;
    }

    public void setContainmentExpression(Containment containmentExpression) {
        this.containmentExpression = containmentExpression;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainmentNotOperator that = (ContainmentNotOperator) o;
        return Objects.equals(containmentExpression, that.containmentExpression);
    }

    @Override
    public int hashCode() {
        return Objects.hash(containmentExpression);
    }

    @Override
    public String toString() {
        return "ContainmentNotOperator{" + "containmentExpression=" + containmentExpression + '}';
    }
}
